# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.10.4] 2024-09-28

### Added

### Changed

### Removed


## [0.10.3] 2024-09-27

### Added

### Changed

### Removed


## [0.10.2] 2024-09-27

### Added

### Changed

### Removed


## [0.10.1] 2024-09-26

### Added

### Changed
* Bind to AIXD 0.12.1
* PlotContoursRequest plots now all the last requested designs
* Fixed small issues on documentation

### Removed


## [0.10.0] 2024-09-11

### Added

### Changed

* Pin dependency to AIXD version 0.12.0
* Updated examples & documentation
* Fixed domain init in DataInt
* Changed output options in Plot components.
* Fixed Windows install script trying to install from offline wheels.
* Fixed issues related to using ARA on Mac.

### Removed

* Removed option for static plots.

## [0.9.3] 2024-06-18

### Added

### Changed

### Removed


## [0.9.2] 2024-05-07

### Added

### Changed

### Removed


## [0.9.1] 2024-05-07

### Added

### Changed

### Removed


## [0.9.0] 2024-05-07

### Added

### Changed

### Removed

